# REQ-002: Token Refresh Functionality

## Overview

This requirement specifies token refresh functionality. It depends on the user login functionality specified in [REQ-001](REQ-001).

This requirement implements the same service contract [CTR-001](CTR-001) as the login functionality.

Users shall be able to refresh their authentication tokens without re-entering credentials, provided their refresh token is still valid.

## Acceptance Criteria

### AC-01: Valid Refresh Token

Given a user with a valid refresh token
When they request a new access token
Then they receive a new JWT access token
And the refresh token remains valid

### AC-02: Expired Refresh Token

Given a user with an expired refresh token
When they request a new access token
Then they receive an authentication error
And must login again using [REQ-001](REQ-001)
